pub enum HttpAclError {
HostDenied {
host: String,
},
}Expand description
An error that can occur when resolving a host.
Returned by HttpAclDnsResolver when a hostname itself is denied by the ACL.
Downcast the boxed error from a failed resolution to check for this specifically,
as opposed to a lower-level resolution failure.
Variants